@@ -49,8 +49,7 @@ test_dependencies = [
 
 nox.options.sessions = [
     # TODO(https://github.com/googleapis/google-api-python-client/issues/2622):
-    # Remove or restore testing for Python 3.7/3.8
-    "unit-3.9",
+    # Remove or restore testing for Python 3.7/3.8/3.9
     "unit-3.10",
     "unit-3.11",
     "unit-3.12",
